@@ -220,13 +220,18 @@ or run following commands before running 'statehub register-cluster`
 
     pub(super) async fn setup_configmap_helper(
         &self,
+        kubectl: &k8s::Kubectl,
         cluster: &v0::Cluster,
         helm: &k8s::Helm,
     ) -> anyhow::Result<()> {
         let namespace = helm.namespace();
         let default_state = helm.default_state().unwrap_or("");
         let api = self.api.url("");
-        k8s::store_configmap(namespace, &cluster.name, default_state, &api).await?;
+
+        kubectl
+            .store_configmap(namespace, &cluster.name, default_state, &api)
+            .await?;
+
         Ok(())
     }
 
