@@ -407,11 +407,11 @@ impl Cli {
                 skip_helm,
                 provider,
             } => {
-                let name = name.or_else(k8s::get_current_cluster_name).ok_or_else(|| {
-                    anyhow::anyhow!(
-                        "No default Kubernetes context found, need to provide cluster name"
-                    )
-                })?;
+                let kubectl = if let Some(context) = name.as_deref() {
+                    k8s::Kubectl::with_context(context).await?
+                } else {
+                    k8s::Kubectl::new().await?
+                };
                 let no_default_storage_class = if no_state {
                     true
                 } else {
@@ -428,7 +428,7 @@ impl Cli {
                 let claim_unowned_states = !no_state_owner;
                 let helm = k8s::Helm::new(namespace, default_state, skip_helm);
                 statehub
-                    .register_cluster(name, provider, states, helm, claim_unowned_states)
+                    .register_single_cluster(kubectl, provider, states, helm, claim_unowned_states)
                     .await
             }
             Command::UnregisterCluster { force, name } => {
@@ -613,9 +613,13 @@ impl StateHub {
             .print(&self.stdout, self.json)
     }
 
-    async fn register_cluster(
+    async fn _register_multiple_clusters(&self) -> anyhow::Result<()> {
+        Ok(())
+    }
+
+    async fn register_single_cluster(
         &self,
-        cluster: v0::ClusterName,
+        kubectl: k8s::Kubectl,
         provider: Option<v0::Provider>,
         states: Option<Vec<v0::StateName>>,
         helm: k8s::Helm,
@@ -628,7 +632,7 @@ impl StateHub {
             helm.skip()
         };
 
-        let locations = k8s::collect_node_locations().await?;
+        let locations = kubectl.collect_node_locations().await?;
 
         if let Some(ref states) = states {
             self.adjust_all_states(states, &locations, false).await?;
@@ -639,12 +643,13 @@ impl StateHub {
         let provider = if let Some(provider) = provider {
             provider
         } else {
-            k8s::get_cluster_provider(&cluster).await?
+            kubectl.get_cluster_provider().await?
         };
 
+        let cluster_name = kubectl.cluster_name();
         let cluster = self
             .api
-            .register_cluster(&cluster, provider, &locations)
+            .register_cluster(&cluster_name, provider, &locations)
             .await
             .map(Quiet)?;
 
@@ -658,7 +663,8 @@ impl StateHub {
         k8s::validate_namespace(helm.namespace()).await?;
 
         self.setup_cluster_token_helper(&cluster, &helm).await?;
-        self.setup_configmap_helper(&cluster, &helm).await?;
+        self.setup_configmap_helper(&kubectl, &cluster, &helm)
+            .await?;
 
         if claim_unowned_states {
             self.claim_unowned_states_helper(&cluster, states).await?;
@@ -860,18 +866,23 @@ impl StateHub {
     async fn setup_configmap(
         &self,
         namespace: String,
-        cluster: v0::ClusterName,
+        cluster_name: v0::ClusterName,
         default_state: Option<String>,
     ) -> anyhow::Result<()> {
         let default_state = default_state.as_deref().unwrap_or("");
         let api = self.api.url("");
-        let _configmap = k8s::store_configmap(&namespace, &cluster, default_state, &api).await?;
+        k8s::Kubectl::with_context(&cluster_name)
+            .await?
+            .store_configmap(&namespace, &cluster_name, default_state, &api)
+            .await?;
 
         Ok(())
     }
 
     async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
-        k8s::get_regions(zone)
+        k8s::Kubectl::new()
+            .await?
+            .get_regions(zone)
             .await
             .map(|map| {
                 map.into_iter()
